/*
    Copyright (C) 2000 Paul Barton-Davis 

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    $Id: constbuffer.c,v 1.2 2000/10/29 04:42:51 pbd Exp $
*/

#include <limits.h>
#include "constbuffer.h"

/*
    CONST Buffer implementation. This is used wherever stretches of
    a single value are required. This is common for the intended clients
    of this library, where the value would most likely be zero (audio silence).
*/

static BufferType
const_buffer_type (buffer_t *buf)

{
	return ConstBuffer;
}

static gchar *
const_buffer_id (buffer_t *buf)

{
	gchar str[32];
	const_buffer_t *cb = (const_buffer_t *) buf->private_data;
	sprintf (str, "%d", cb->value);
	return g_strdup (str);
}

static guint32
const_buffer_length (buffer_t *buf)

{
	return UINT_MAX; /* max bytes in a single memset() */
}

static guint32
const_buffer_read (buffer_t *src, buffer_data_t *dst, guint32 start, guint32 cnt) 
{
	const_buffer_t *cb = (const_buffer_t *) src->private_data;
	guint32 n = cnt;
	while (n--) *dst++ = cb->value;
	return cnt;
}

static piece_t *
const_buffer_append_data (buffer_t *dst, buffer_data_t *src, guint32 cnt) 
{
	return NULL;
}

guint32
const_buffer_append (buffer_t *dst, buffer_t *src, guint32 start, guint32 cnt)
{
	return cnt;
}

buffer_t *
const_buffer_clone (buffer_t *self)

{
	return self;
}

void
const_buffer_close (buffer_t *self)

{
	const_buffer_t *cb = (const_buffer_t *) self->private_data;
	g_free (cb);
}

buffer_t *
const_buffer_new (guchar val)

{
	const_buffer_t *cb = g_malloc (sizeof (const_buffer_t));
	
	cb->value = val;

	return buffer_new (const_buffer_type,
			   const_buffer_id,
			   const_buffer_length,
			   const_buffer_read,
			   const_buffer_clone,
			   const_buffer_append,
			   const_buffer_append_data,
			   const_buffer_close,
			   cb);
}
